searchNodes=[{"ref":"Money.html","title":"Money","type":"module","doc":"Defines a Money struct along with convenience methods for working with currencies. Example: iex&gt; money = Money.new(500, :USD) %Money{amount: 500, currency: :USD} iex&gt; money = Money.add(money, 550) %Money{amount: 1050, currency: :USD} iex&gt; Money.to_string(money) &quot;$10.50&quot; Configuration options You can set defaults in your Mix configuration to make working with Money a little easier. Configuration: config :money, default_currency: :EUR, # this allows you to do Money.new(100) separator: &quot;.&quot;, # change the default thousands separator for Money.to_string delimiter: &quot;,&quot;, # change the default decimal delimeter for Money.to_string symbol: false # don’t display the currency symbol in Money.to_string symbol_on_right: false, # position the symbol symbol_space: false # add a space between symbol and number fractional_unit: true # display units after the delimeter strip_insignificant_zeros: false # don’t display the insignificant zeros or the delimeter"},{"ref":"Money.html#abs/1","title":"Money.abs/1","type":"function","doc":"Returns a Money with the arithmetical absolute of the amount. Examples: iex&gt; Money.new(-100, :USD) |&gt; Money.abs %Money{amount: 100, currency: :USD} iex&gt; Money.new(100, :USD) |&gt; Money.abs %Money{amount: 100, currency: :USD}"},{"ref":"Money.html#add/2","title":"Money.add/2","type":"function","doc":"Adds two Money together or an integer (cents) amount to a Money Example: iex&gt; Money.add(Money.new(100, :USD), Money.new(50, :USD)) %Money{amount: 150, currency: :USD} iex&gt; Money.add(Money.new(100, :USD), 50) %Money{amount: 150, currency: :USD} iex&gt; Money.add(Money.new(100, :USD), 5.55) %Money{amount: 655, currency: :USD}"},{"ref":"Money.html#compare/2","title":"Money.compare/2","type":"function","doc":"Compares two Money structs with each other. They must each be of the same currency and then their amounts are compared Example: iex&gt; Money.compare(Money.new(100, :USD), Money.new(100, :USD)) 0 iex&gt; Money.compare(Money.new(100, :USD), Money.new(101, :USD)) -1 iex&gt; Money.compare(Money.new(101, :USD), Money.new(100, :USD)) 1"},{"ref":"Money.html#divide/2","title":"Money.divide/2","type":"function","doc":"Divides up Money by an amount Example: iex&gt; Money.divide(Money.new(100, :USD), 2) [%Money{amount: 50, currency: :USD}, %Money{amount: 50, currency: :USD}] iex&gt; Money.divide(Money.new(101, :USD), 2) [%Money{amount: 51, currency: :USD}, %Money{amount: 50, currency: :USD}]"},{"ref":"Money.html#equals?/2","title":"Money.equals?/2","type":"function","doc":"Returns true if two Money of the same currency have the same amount Example: iex&gt; Money.equals?(Money.new(100, :USD), Money.new(100, :USD)) true iex&gt; Money.equals?(Money.new(101, :USD), Money.new(100, :USD)) false"},{"ref":"Money.html#multiply/2","title":"Money.multiply/2","type":"function","doc":"Multiplies a Money by an amount Example: iex&gt; Money.multiply(Money.new(100, :USD), 10) %Money{amount: 1000, currency: :USD} iex&gt; Money.multiply(Money.new(100, :USD), 1.5) %Money{amount: 150, currency: :USD}"},{"ref":"Money.html#neg/1","title":"Money.neg/1","type":"function","doc":"Returns a Money with the amount negated. Examples: iex&gt; Money.new(100, :USD) |&gt; Money.neg %Money{amount: -100, currency: :USD} iex&gt; Money.new(-100, :USD) |&gt; Money.neg %Money{amount: 100, currency: :USD}"},{"ref":"Money.html#negative?/1","title":"Money.negative?/1","type":"function","doc":"Returns true if the amount of a Money is less than zero Example: iex&gt; Money.negative?(Money.new(0, :USD)) false iex&gt; Money.negative?(Money.new(1, :USD)) false iex&gt; Money.negative?(Money.new(-1, :USD)) true"},{"ref":"Money.html#new/1","title":"Money.new/1","type":"function","doc":"Create a new Money struct using a default currency. The default currency can be set in the system Mix config. Example Config: config :money, default_currency: :USD Example: Money.new(123) %Money{amount: 123, currency: :USD}"},{"ref":"Money.html#new/2","title":"Money.new/2","type":"function","doc":"Create a new Money struct from currency sub-units (cents) Example: iex&gt; Money.new(1_000_00, :USD) %Money{amount: 1_000_00, currency: :USD}"},{"ref":"Money.html#parse/3","title":"Money.parse/3","type":"function","doc":"Parse a value into a Money type. The following options are available: separator - default &quot;,&quot;, sets the separator for groups of thousands. &quot;1,000&quot; delimiter - default &quot;.&quot;, sets the decimal delimiter. &quot;1.23&quot; Examples: iex&gt; Money.parse(&quot;$1,234.56&quot;, :USD) {:ok, %Money{amount: 123456, currency: :USD}} iex&gt; Money.parse(&quot;1.234,56&quot;, :EUR, separator: &quot;.&quot;, delimiter: &quot;,&quot;) {:ok, %Money{amount: 123456, currency: :EUR}} iex&gt; Money.parse(&quot;1.234,56&quot;, :WRONG) :error iex&gt; Money.parse(1_234.56, :USD) {:ok, %Money{amount: 123456, currency: :USD}} iex&gt; Money.parse(-1_234.56, :USD) {:ok, %Money{amount: -123456, currency: :USD}}"},{"ref":"Money.html#parse!/3","title":"Money.parse!/3","type":"function","doc":"Parse a value into a Money type. Similar to parse/3 but returns a %Money{} or raises an error if parsing fails. Example: iex&gt; Money.parse!(&quot;1,234.56&quot;, :USD) %Money{amount: 123456, currency: :USD} iex&gt; Money.parse!(&quot;wrong&quot;, :USD) ** (ArgumentError) unable to parse &quot;wrong&quot;"},{"ref":"Money.html#positive?/1","title":"Money.positive?/1","type":"function","doc":"Returns true if the amount of a Money is greater than zero Example: iex&gt; Money.positive?(Money.new(0, :USD)) false iex&gt; Money.positive?(Money.new(1, :USD)) true iex&gt; Money.positive?(Money.new(-1, :USD)) false"},{"ref":"Money.html#subtract/2","title":"Money.subtract/2","type":"function","doc":"Subtracts one Money from another or an integer (cents) from a Money Example: iex&gt; Money.subtract(Money.new(150, :USD), Money.new(50, :USD)) %Money{amount: 100, currency: :USD} iex&gt; Money.subtract(Money.new(150, :USD), 50) %Money{amount: 100, currency: :USD} iex&gt; Money.subtract(Money.new(150, :USD), 1.25) %Money{amount: 25, currency: :USD}"},{"ref":"Money.html#to_string/2","title":"Money.to_string/2","type":"function","doc":"Converts a Money struct to a string representation The following options are available: separator - default &quot;,&quot;, sets the separator for groups of thousands. &quot;1,000&quot; delimiter - default &quot;.&quot;, sets the decimal delimiter. &quot;1.23&quot; symbol - default true, sets whether to display the currency symbol or not. symbol_on_right - default false, display the currency symbol on the right of the number, eg: 123.45€ symbol_space - default false, add a space between currency symbol and number, eg: € 123,45 or 123.45 € fractional_unit - default true, show the remaining units after the delimeter strip_insignificant_zeros - default false, strip zeros after the delimeter Example: iex&gt; Money.to_string(Money.new(123456, :GBP)) &quot;£1,234.56&quot; iex&gt; Money.to_string(Money.new(123456, :EUR), separator: &quot;.&quot;, delimiter: &quot;,&quot;) &quot;€1.234,56&quot; iex&gt; Money.to_string(Money.new(123456, :EUR), symbol: false) &quot;1,234.56&quot; iex&gt; Money.to_string(Money.new(123456, :EUR), symbol: false, separator: &quot;&quot;) &quot;1234.56&quot; iex&gt; Money.to_string(Money.new(123456, :EUR), fractional_unit: false) &quot;€1,234&quot; iex&gt; Money.to_string(Money.new(123450, :EUR), strip_insignificant_zeros: true) &quot;€1,234.5&quot; It can also be interpolated (It implements the String.Chars protocol) To control the formatting, you can use the above options in your config, more information is in the introduction to Money Example: iex&gt; &quot;Total: \#{Money.new(100_00, :USD)}&quot; &quot;Total: $100.00&quot;"},{"ref":"Money.html#zero?/1","title":"Money.zero?/1","type":"function","doc":"Returns true if the amount of a Money struct is zero Example: iex&gt; Money.zero?(Money.new(0, :USD)) true iex&gt; Money.zero?(Money.new(1, :USD)) false"},{"ref":"Money.html#t:t/0","title":"Money.t/0","type":"type","doc":""},{"ref":"Money.Currency.html","title":"Money.Currency","type":"module","doc":"Provides currency support to Money Some useful helper methods include: get/1 get!/1 exists?/1 to_atom/1 name/1 name!/1 symbol/1 symbol!/1 all/0 A helper function exists for each currency using the lowercase three-character currency code Example: iex&gt; Money.Currency.usd(100) %Money{amount: 100, currency: :USD}"},{"ref":"Money.Currency.html#aed/1","title":"Money.Currency.aed/1","type":"function","doc":"Convenience method to create a Money object for the UAE Dirham (AED) currency. Example: iex&gt; Money.Currency.aed(100) %Money{amount: 100, currency: :AED}"},{"ref":"Money.Currency.html#afn/1","title":"Money.Currency.afn/1","type":"function","doc":"Convenience method to create a Money object for the Afghani (AFN) currency. Example: iex&gt; Money.Currency.afn(100) %Money{amount: 100, currency: :AFN}"},{"ref":"Money.Currency.html#all/0","title":"Money.Currency.all/0","type":"function","doc":"Returns all the currencies Example: iex&gt; Money.Currency.all |&gt; Map.fetch!(:GBP) %{name: &quot;Pound Sterling&quot;, symbol: &quot;£&quot;, exponent: 2}"},{"ref":"Money.Currency.html#all/1","title":"Money.Currency.all/1","type":"function","doc":"Convenience method to create a Money object for the Lek (ALL) currency. Example: iex&gt; Money.Currency.all(100) %Money{amount: 100, currency: :ALL}"},{"ref":"Money.Currency.html#amd/1","title":"Money.Currency.amd/1","type":"function","doc":"Convenience method to create a Money object for the Armenian Dram (AMD) currency. Example: iex&gt; Money.Currency.amd(100) %Money{amount: 100, currency: :AMD}"},{"ref":"Money.Currency.html#ang/1","title":"Money.Currency.ang/1","type":"function","doc":"Convenience method to create a Money object for the Netherlands Antillian Guilder (ANG) currency. Example: iex&gt; Money.Currency.ang(100) %Money{amount: 100, currency: :ANG}"},{"ref":"Money.Currency.html#aoa/1","title":"Money.Currency.aoa/1","type":"function","doc":"Convenience method to create a Money object for the Kwanza (AOA) currency. Example: iex&gt; Money.Currency.aoa(100) %Money{amount: 100, currency: :AOA}"},{"ref":"Money.Currency.html#ars/1","title":"Money.Currency.ars/1","type":"function","doc":"Convenience method to create a Money object for the Argentine Peso (ARS) currency. Example: iex&gt; Money.Currency.ars(100) %Money{amount: 100, currency: :ARS}"},{"ref":"Money.Currency.html#aud/1","title":"Money.Currency.aud/1","type":"function","doc":"Convenience method to create a Money object for the Australian Dollar (AUD) currency. Example: iex&gt; Money.Currency.aud(100) %Money{amount: 100, currency: :AUD}"},{"ref":"Money.Currency.html#awg/1","title":"Money.Currency.awg/1","type":"function","doc":"Convenience method to create a Money object for the Aruban Guilder (AWG) currency. Example: iex&gt; Money.Currency.awg(100) %Money{amount: 100, currency: :AWG}"},{"ref":"Money.Currency.html#azn/1","title":"Money.Currency.azn/1","type":"function","doc":"Convenience method to create a Money object for the Azerbaijanian Manat (AZN) currency. Example: iex&gt; Money.Currency.azn(100) %Money{amount: 100, currency: :AZN}"},{"ref":"Money.Currency.html#bam/1","title":"Money.Currency.bam/1","type":"function","doc":"Convenience method to create a Money object for the Convertible Marks (BAM) currency. Example: iex&gt; Money.Currency.bam(100) %Money{amount: 100, currency: :BAM}"},{"ref":"Money.Currency.html#bbd/1","title":"Money.Currency.bbd/1","type":"function","doc":"Convenience method to create a Money object for the Barbados Dollar (BBD) currency. Example: iex&gt; Money.Currency.bbd(100) %Money{amount: 100, currency: :BBD}"},{"ref":"Money.Currency.html#bdt/1","title":"Money.Currency.bdt/1","type":"function","doc":"Convenience method to create a Money object for the Taka (BDT) currency. Example: iex&gt; Money.Currency.bdt(100) %Money{amount: 100, currency: :BDT}"},{"ref":"Money.Currency.html#bgn/1","title":"Money.Currency.bgn/1","type":"function","doc":"Convenience method to create a Money object for the Bulgarian Lev (BGN) currency. Example: iex&gt; Money.Currency.bgn(100) %Money{amount: 100, currency: :BGN}"},{"ref":"Money.Currency.html#bhd/1","title":"Money.Currency.bhd/1","type":"function","doc":"Convenience method to create a Money object for the Bahraini Dinar (BHD) currency. Example: iex&gt; Money.Currency.bhd(100) %Money{amount: 100, currency: :BHD}"},{"ref":"Money.Currency.html#bif/1","title":"Money.Currency.bif/1","type":"function","doc":"Convenience method to create a Money object for the Burundi Franc (BIF) currency. Example: iex&gt; Money.Currency.bif(100) %Money{amount: 100, currency: :BIF}"},{"ref":"Money.Currency.html#bmd/1","title":"Money.Currency.bmd/1","type":"function","doc":"Convenience method to create a Money object for the Bermudian Dollar (customarily known as Bermuda Dollar) (BMD) currency. Example: iex&gt; Money.Currency.bmd(100) %Money{amount: 100, currency: :BMD}"},{"ref":"Money.Currency.html#bnd/1","title":"Money.Currency.bnd/1","type":"function","doc":"Convenience method to create a Money object for the Brunei Dollar (BND) currency. Example: iex&gt; Money.Currency.bnd(100) %Money{amount: 100, currency: :BND}"},{"ref":"Money.Currency.html#bob/1","title":"Money.Currency.bob/1","type":"function","doc":"Convenience method to create a Money object for the Boliviano Mvdol (BOB) currency. Example: iex&gt; Money.Currency.bob(100) %Money{amount: 100, currency: :BOB}"},{"ref":"Money.Currency.html#bov/1","title":"Money.Currency.bov/1","type":"function","doc":"Convenience method to create a Money object for the Boliviano Mvdol (BOV) currency. Example: iex&gt; Money.Currency.bov(100) %Money{amount: 100, currency: :BOV}"},{"ref":"Money.Currency.html#brl/1","title":"Money.Currency.brl/1","type":"function","doc":"Convenience method to create a Money object for the Brazilian Real (BRL) currency. Example: iex&gt; Money.Currency.brl(100) %Money{amount: 100, currency: :BRL}"},{"ref":"Money.Currency.html#bsd/1","title":"Money.Currency.bsd/1","type":"function","doc":"Convenience method to create a Money object for the Bahamian Dollar (BSD) currency. Example: iex&gt; Money.Currency.bsd(100) %Money{amount: 100, currency: :BSD}"},{"ref":"Money.Currency.html#btn/1","title":"Money.Currency.btn/1","type":"function","doc":"Convenience method to create a Money object for the Indian Rupee Ngultrum (BTN) currency. Example: iex&gt; Money.Currency.btn(100) %Money{amount: 100, currency: :BTN}"},{"ref":"Money.Currency.html#bwp/1","title":"Money.Currency.bwp/1","type":"function","doc":"Convenience method to create a Money object for the Pula (BWP) currency. Example: iex&gt; Money.Currency.bwp(100) %Money{amount: 100, currency: :BWP}"},{"ref":"Money.Currency.html#byn/1","title":"Money.Currency.byn/1","type":"function","doc":"Convenience method to create a Money object for the Belarusian Ruble (BYN) currency. Example: iex&gt; Money.Currency.byn(100) %Money{amount: 100, currency: :BYN}"},{"ref":"Money.Currency.html#byr/1","title":"Money.Currency.byr/1","type":"function","doc":"Convenience method to create a Money object for the Belarusian Ruble (BYR) currency. Example: iex&gt; Money.Currency.byr(100) %Money{amount: 100, currency: :BYR}"},{"ref":"Money.Currency.html#bzd/1","title":"Money.Currency.bzd/1","type":"function","doc":"Convenience method to create a Money object for the Belize Dollar (BZD) currency. Example: iex&gt; Money.Currency.bzd(100) %Money{amount: 100, currency: :BZD}"},{"ref":"Money.Currency.html#cad/1","title":"Money.Currency.cad/1","type":"function","doc":"Convenience method to create a Money object for the Canadian Dollar (CAD) currency. Example: iex&gt; Money.Currency.cad(100) %Money{amount: 100, currency: :CAD}"},{"ref":"Money.Currency.html#cdf/1","title":"Money.Currency.cdf/1","type":"function","doc":"Convenience method to create a Money object for the Congolese Franc (CDF) currency. Example: iex&gt; Money.Currency.cdf(100) %Money{amount: 100, currency: :CDF}"},{"ref":"Money.Currency.html#chf/1","title":"Money.Currency.chf/1","type":"function","doc":"Convenience method to create a Money object for the Swiss Franc (CHF) currency. Example: iex&gt; Money.Currency.chf(100) %Money{amount: 100, currency: :CHF}"},{"ref":"Money.Currency.html#clf/1","title":"Money.Currency.clf/1","type":"function","doc":"Convenience method to create a Money object for the Chilean Peso Unidades de fomento (CLF) currency. Example: iex&gt; Money.Currency.clf(100) %Money{amount: 100, currency: :CLF}"},{"ref":"Money.Currency.html#clp/1","title":"Money.Currency.clp/1","type":"function","doc":"Convenience method to create a Money object for the Chilean Peso Unidades de fomento (CLP) currency. Example: iex&gt; Money.Currency.clp(100) %Money{amount: 100, currency: :CLP}"},{"ref":"Money.Currency.html#cny/1","title":"Money.Currency.cny/1","type":"function","doc":"Convenience method to create a Money object for the Yuan Renminbi (CNY) currency. Example: iex&gt; Money.Currency.cny(100) %Money{amount: 100, currency: :CNY}"},{"ref":"Money.Currency.html#cop/1","title":"Money.Currency.cop/1","type":"function","doc":"Convenience method to create a Money object for the Colombian Peso (COP) currency. Example: iex&gt; Money.Currency.cop(100) %Money{amount: 100, currency: :COP}"},{"ref":"Money.Currency.html#cou/1","title":"Money.Currency.cou/1","type":"function","doc":"Convenience method to create a Money object for the Colombian Peso Unidad de Valor Real (COU) currency. Example: iex&gt; Money.Currency.cou(100) %Money{amount: 100, currency: :COU}"},{"ref":"Money.Currency.html#crc/1","title":"Money.Currency.crc/1","type":"function","doc":"Convenience method to create a Money object for the Costa Rican Colon (CRC) currency. Example: iex&gt; Money.Currency.crc(100) %Money{amount: 100, currency: :CRC}"},{"ref":"Money.Currency.html#cuc/1","title":"Money.Currency.cuc/1","type":"function","doc":"Convenience method to create a Money object for the Cuban Peso Peso Convertible (CUC) currency. Example: iex&gt; Money.Currency.cuc(100) %Money{amount: 100, currency: :CUC}"},{"ref":"Money.Currency.html#cup/1","title":"Money.Currency.cup/1","type":"function","doc":"Convenience method to create a Money object for the Cuban Peso Peso Convertible (CUP) currency. Example: iex&gt; Money.Currency.cup(100) %Money{amount: 100, currency: :CUP}"},{"ref":"Money.Currency.html#cve/1","title":"Money.Currency.cve/1","type":"function","doc":"Convenience method to create a Money object for the Cape Verde Escudo (CVE) currency. Example: iex&gt; Money.Currency.cve(100) %Money{amount: 100, currency: :CVE}"},{"ref":"Money.Currency.html#czk/1","title":"Money.Currency.czk/1","type":"function","doc":"Convenience method to create a Money object for the Czech Koruna (CZK) currency. Example: iex&gt; Money.Currency.czk(100) %Money{amount: 100, currency: :CZK}"},{"ref":"Money.Currency.html#djf/1","title":"Money.Currency.djf/1","type":"function","doc":"Convenience method to create a Money object for the Djibouti Franc (DJF) currency. Example: iex&gt; Money.Currency.djf(100) %Money{amount: 100, currency: :DJF}"},{"ref":"Money.Currency.html#dkk/1","title":"Money.Currency.dkk/1","type":"function","doc":"Convenience method to create a Money object for the Danish Krone (DKK) currency. Example: iex&gt; Money.Currency.dkk(100) %Money{amount: 100, currency: :DKK}"},{"ref":"Money.Currency.html#dop/1","title":"Money.Currency.dop/1","type":"function","doc":"Convenience method to create a Money object for the Dominican Peso (DOP) currency. Example: iex&gt; Money.Currency.dop(100) %Money{amount: 100, currency: :DOP}"},{"ref":"Money.Currency.html#dzd/1","title":"Money.Currency.dzd/1","type":"function","doc":"Convenience method to create a Money object for the Algerian Dinar (DZD) currency. Example: iex&gt; Money.Currency.dzd(100) %Money{amount: 100, currency: :DZD}"},{"ref":"Money.Currency.html#eek/1","title":"Money.Currency.eek/1","type":"function","doc":"Convenience method to create a Money object for the Kroon (EEK) currency. Example: iex&gt; Money.Currency.eek(100) %Money{amount: 100, currency: :EEK}"},{"ref":"Money.Currency.html#egp/1","title":"Money.Currency.egp/1","type":"function","doc":"Convenience method to create a Money object for the Egyptian Pound (EGP) currency. Example: iex&gt; Money.Currency.egp(100) %Money{amount: 100, currency: :EGP}"},{"ref":"Money.Currency.html#ern/1","title":"Money.Currency.ern/1","type":"function","doc":"Convenience method to create a Money object for the Nakfa (ERN) currency. Example: iex&gt; Money.Currency.ern(100) %Money{amount: 100, currency: :ERN}"},{"ref":"Money.Currency.html#etb/1","title":"Money.Currency.etb/1","type":"function","doc":"Convenience method to create a Money object for the Ethiopian Birr (ETB) currency. Example: iex&gt; Money.Currency.etb(100) %Money{amount: 100, currency: :ETB}"},{"ref":"Money.Currency.html#eur/1","title":"Money.Currency.eur/1","type":"function","doc":"Convenience method to create a Money object for the Euro (EUR) currency. Example: iex&gt; Money.Currency.eur(100) %Money{amount: 100, currency: :EUR}"},{"ref":"Money.Currency.html#exists?/1","title":"Money.Currency.exists?/1","type":"function","doc":"Returns true if a currency is defined Example: iex&gt; Money.Currency.exists?(:USD) true iex&gt; Money.Currency.exists?(&quot;USD&quot;) true iex&gt; Money.Currency.exists?(:WRONG) false"},{"ref":"Money.Currency.html#exponent/1","title":"Money.Currency.exponent/1","type":"function","doc":"Returns the exponent of the currency or nil if it doesn’t exist. Example: iex&gt; Money.Currency.exponent(:USD) 2 iex&gt; Money.Currency.exponent(:WRONG) nil"},{"ref":"Money.Currency.html#exponent!/1","title":"Money.Currency.exponent!/1","type":"function","doc":"Returns the exponent of the currency. An ArgumentError is raised if the currency doesn’t exist. Example: iex&gt; Money.Currency.exponent!(:USD) 2 iex&gt; Money.Currency.exponent!(:WRONG) ** (ArgumentError) currency WRONG doesn’t exist"},{"ref":"Money.Currency.html#fjd/1","title":"Money.Currency.fjd/1","type":"function","doc":"Convenience method to create a Money object for the Fiji Dollar (FJD) currency. Example: iex&gt; Money.Currency.fjd(100) %Money{amount: 100, currency: :FJD}"},{"ref":"Money.Currency.html#fkp/1","title":"Money.Currency.fkp/1","type":"function","doc":"Convenience method to create a Money object for the Falkland Islands Pound (FKP) currency. Example: iex&gt; Money.Currency.fkp(100) %Money{amount: 100, currency: :FKP}"},{"ref":"Money.Currency.html#gbp/1","title":"Money.Currency.gbp/1","type":"function","doc":"Convenience method to create a Money object for the Pound Sterling (GBP) currency. Example: iex&gt; Money.Currency.gbp(100) %Money{amount: 100, currency: :GBP}"},{"ref":"Money.Currency.html#gel/1","title":"Money.Currency.gel/1","type":"function","doc":"Convenience method to create a Money object for the Lari (GEL) currency. Example: iex&gt; Money.Currency.gel(100) %Money{amount: 100, currency: :GEL}"},{"ref":"Money.Currency.html#get/1","title":"Money.Currency.get/1","type":"function","doc":"Returns a map with the name and symbol of the currency or nil if it doesn’t exist. Example: iex&gt; Money.Currency.get(:USD) %{name: &quot;US Dollar&quot;, symbol: &quot;$&quot;, exponent: 2} iex&gt; Money.Currency.get(:WRONG) nil"},{"ref":"Money.Currency.html#get!/1","title":"Money.Currency.get!/1","type":"function","doc":"Returns a map with the name and symbol of the currency. An ArgumentError is raised if the currency doesn’t exist. Example: iex&gt; Money.Currency.get!(:USD) %{name: &quot;US Dollar&quot;, symbol: &quot;$&quot;, exponent: 2} iex&gt; Money.Currency.get!(:WRONG) ** (ArgumentError) currency WRONG doesn’t exist"},{"ref":"Money.Currency.html#ghs/1","title":"Money.Currency.ghs/1","type":"function","doc":"Convenience method to create a Money object for the Cedi (GHS) currency. Example: iex&gt; Money.Currency.ghs(100) %Money{amount: 100, currency: :GHS}"},{"ref":"Money.Currency.html#gip/1","title":"Money.Currency.gip/1","type":"function","doc":"Convenience method to create a Money object for the Gibraltar Pound (GIP) currency. Example: iex&gt; Money.Currency.gip(100) %Money{amount: 100, currency: :GIP}"},{"ref":"Money.Currency.html#gmd/1","title":"Money.Currency.gmd/1","type":"function","doc":"Convenience method to create a Money object for the Dalasi (GMD) currency. Example: iex&gt; Money.Currency.gmd(100) %Money{amount: 100, currency: :GMD}"},{"ref":"Money.Currency.html#gnf/1","title":"Money.Currency.gnf/1","type":"function","doc":"Convenience method to create a Money object for the Guinea Franc (GNF) currency. Example: iex&gt; Money.Currency.gnf(100) %Money{amount: 100, currency: :GNF}"},{"ref":"Money.Currency.html#gtq/1","title":"Money.Currency.gtq/1","type":"function","doc":"Convenience method to create a Money object for the Quetzal (GTQ) currency. Example: iex&gt; Money.Currency.gtq(100) %Money{amount: 100, currency: :GTQ}"},{"ref":"Money.Currency.html#gyd/1","title":"Money.Currency.gyd/1","type":"function","doc":"Convenience method to create a Money object for the Guyana Dollar (GYD) currency. Example: iex&gt; Money.Currency.gyd(100) %Money{amount: 100, currency: :GYD}"},{"ref":"Money.Currency.html#hkd/1","title":"Money.Currency.hkd/1","type":"function","doc":"Convenience method to create a Money object for the Hong Kong Dollar (HKD) currency. Example: iex&gt; Money.Currency.hkd(100) %Money{amount: 100, currency: :HKD}"},{"ref":"Money.Currency.html#hnl/1","title":"Money.Currency.hnl/1","type":"function","doc":"Convenience method to create a Money object for the Lempira (HNL) currency. Example: iex&gt; Money.Currency.hnl(100) %Money{amount: 100, currency: :HNL}"},{"ref":"Money.Currency.html#hrk/1","title":"Money.Currency.hrk/1","type":"function","doc":"Convenience method to create a Money object for the Croatian Kuna (HRK) currency. Example: iex&gt; Money.Currency.hrk(100) %Money{amount: 100, currency: :HRK}"},{"ref":"Money.Currency.html#htg/1","title":"Money.Currency.htg/1","type":"function","doc":"Convenience method to create a Money object for the Gourde US Dollar (HTG) currency. Example: iex&gt; Money.Currency.htg(100) %Money{amount: 100, currency: :HTG}"},{"ref":"Money.Currency.html#huf/1","title":"Money.Currency.huf/1","type":"function","doc":"Convenience method to create a Money object for the Forint (HUF) currency. Example: iex&gt; Money.Currency.huf(100) %Money{amount: 100, currency: :HUF}"},{"ref":"Money.Currency.html#idr/1","title":"Money.Currency.idr/1","type":"function","doc":"Convenience method to create a Money object for the Rupiah (IDR) currency. Example: iex&gt; Money.Currency.idr(100) %Money{amount: 100, currency: :IDR}"},{"ref":"Money.Currency.html#ils/1","title":"Money.Currency.ils/1","type":"function","doc":"Convenience method to create a Money object for the New Israeli Sheqel (ILS) currency. Example: iex&gt; Money.Currency.ils(100) %Money{amount: 100, currency: :ILS}"},{"ref":"Money.Currency.html#inr/1","title":"Money.Currency.inr/1","type":"function","doc":"Convenience method to create a Money object for the Indian Rupee (INR) currency. Example: iex&gt; Money.Currency.inr(100) %Money{amount: 100, currency: :INR}"},{"ref":"Money.Currency.html#iqd/1","title":"Money.Currency.iqd/1","type":"function","doc":"Convenience method to create a Money object for the Iraqi Dinar (IQD) currency. Example: iex&gt; Money.Currency.iqd(100) %Money{amount: 100, currency: :IQD}"},{"ref":"Money.Currency.html#irr/1","title":"Money.Currency.irr/1","type":"function","doc":"Convenience method to create a Money object for the Iranian Rial (IRR) currency. Example: iex&gt; Money.Currency.irr(100) %Money{amount: 100, currency: :IRR}"},{"ref":"Money.Currency.html#isk/1","title":"Money.Currency.isk/1","type":"function","doc":"Convenience method to create a Money object for the Iceland Krona (ISK) currency. Example: iex&gt; Money.Currency.isk(100) %Money{amount: 100, currency: :ISK}"},{"ref":"Money.Currency.html#jmd/1","title":"Money.Currency.jmd/1","type":"function","doc":"Convenience method to create a Money object for the Jamaican Dollar (JMD) currency. Example: iex&gt; Money.Currency.jmd(100) %Money{amount: 100, currency: :JMD}"},{"ref":"Money.Currency.html#jod/1","title":"Money.Currency.jod/1","type":"function","doc":"Convenience method to create a Money object for the Jordanian Dinar (JOD) currency. Example: iex&gt; Money.Currency.jod(100) %Money{amount: 100, currency: :JOD}"},{"ref":"Money.Currency.html#jpy/1","title":"Money.Currency.jpy/1","type":"function","doc":"Convenience method to create a Money object for the Yen (JPY) currency. Example: iex&gt; Money.Currency.jpy(100) %Money{amount: 100, currency: :JPY}"},{"ref":"Money.Currency.html#kes/1","title":"Money.Currency.kes/1","type":"function","doc":"Convenience method to create a Money object for the Kenyan Shilling (KES) currency. Example: iex&gt; Money.Currency.kes(100) %Money{amount: 100, currency: :KES}"},{"ref":"Money.Currency.html#kgs/1","title":"Money.Currency.kgs/1","type":"function","doc":"Convenience method to create a Money object for the Som (KGS) currency. Example: iex&gt; Money.Currency.kgs(100) %Money{amount: 100, currency: :KGS}"},{"ref":"Money.Currency.html#khr/1","title":"Money.Currency.khr/1","type":"function","doc":"Convenience method to create a Money object for the Riel (KHR) currency. Example: iex&gt; Money.Currency.khr(100) %Money{amount: 100, currency: :KHR}"},{"ref":"Money.Currency.html#kmf/1","title":"Money.Currency.kmf/1","type":"function","doc":"Convenience method to create a Money object for the Comoro Franc (KMF) currency. Example: iex&gt; Money.Currency.kmf(100) %Money{amount: 100, currency: :KMF}"},{"ref":"Money.Currency.html#kpw/1","title":"Money.Currency.kpw/1","type":"function","doc":"Convenience method to create a Money object for the North Korean Won (KPW) currency. Example: iex&gt; Money.Currency.kpw(100) %Money{amount: 100, currency: :KPW}"},{"ref":"Money.Currency.html#krw/1","title":"Money.Currency.krw/1","type":"function","doc":"Convenience method to create a Money object for the Won (KRW) currency. Example: iex&gt; Money.Currency.krw(100) %Money{amount: 100, currency: :KRW}"},{"ref":"Money.Currency.html#kwd/1","title":"Money.Currency.kwd/1","type":"function","doc":"Convenience method to create a Money object for the Kuwaiti Dinar (KWD) currency. Example: iex&gt; Money.Currency.kwd(100) %Money{amount: 100, currency: :KWD}"},{"ref":"Money.Currency.html#kyd/1","title":"Money.Currency.kyd/1","type":"function","doc":"Convenience method to create a Money object for the Cayman Islands Dollar (KYD) currency. Example: iex&gt; Money.Currency.kyd(100) %Money{amount: 100, currency: :KYD}"},{"ref":"Money.Currency.html#kzt/1","title":"Money.Currency.kzt/1","type":"function","doc":"Convenience method to create a Money object for the Tenge (KZT) currency. Example: iex&gt; Money.Currency.kzt(100) %Money{amount: 100, currency: :KZT}"},{"ref":"Money.Currency.html#lak/1","title":"Money.Currency.lak/1","type":"function","doc":"Convenience method to create a Money object for the Kip (LAK) currency. Example: iex&gt; Money.Currency.lak(100) %Money{amount: 100, currency: :LAK}"},{"ref":"Money.Currency.html#lbp/1","title":"Money.Currency.lbp/1","type":"function","doc":"Convenience method to create a Money object for the Lebanese Pound (LBP) currency. Example: iex&gt; Money.Currency.lbp(100) %Money{amount: 100, currency: :LBP}"},{"ref":"Money.Currency.html#lkr/1","title":"Money.Currency.lkr/1","type":"function","doc":"Convenience method to create a Money object for the Sri Lanka Rupee (LKR) currency. Example: iex&gt; Money.Currency.lkr(100) %Money{amount: 100, currency: :LKR}"},{"ref":"Money.Currency.html#lrd/1","title":"Money.Currency.lrd/1","type":"function","doc":"Convenience method to create a Money object for the Liberian Dollar (LRD) currency. Example: iex&gt; Money.Currency.lrd(100) %Money{amount: 100, currency: :LRD}"},{"ref":"Money.Currency.html#lsl/1","title":"Money.Currency.lsl/1","type":"function","doc":"Convenience method to create a Money object for the Rand Loti (LSL) currency. Example: iex&gt; Money.Currency.lsl(100) %Money{amount: 100, currency: :LSL}"},{"ref":"Money.Currency.html#ltl/1","title":"Money.Currency.ltl/1","type":"function","doc":"Convenience method to create a Money object for the Lithuanian Litas (LTL) currency. Example: iex&gt; Money.Currency.ltl(100) %Money{amount: 100, currency: :LTL}"},{"ref":"Money.Currency.html#lvl/1","title":"Money.Currency.lvl/1","type":"function","doc":"Convenience method to create a Money object for the Latvian Lats (LVL) currency. Example: iex&gt; Money.Currency.lvl(100) %Money{amount: 100, currency: :LVL}"},{"ref":"Money.Currency.html#lyd/1","title":"Money.Currency.lyd/1","type":"function","doc":"Convenience method to create a Money object for the Libyan Dinar (LYD) currency. Example: iex&gt; Money.Currency.lyd(100) %Money{amount: 100, currency: :LYD}"},{"ref":"Money.Currency.html#mad/1","title":"Money.Currency.mad/1","type":"function","doc":"Convenience method to create a Money object for the Moroccan Dirham (MAD) currency. Example: iex&gt; Money.Currency.mad(100) %Money{amount: 100, currency: :MAD}"},{"ref":"Money.Currency.html#mdl/1","title":"Money.Currency.mdl/1","type":"function","doc":"Convenience method to create a Money object for the Moldovan Leu (MDL) currency. Example: iex&gt; Money.Currency.mdl(100) %Money{amount: 100, currency: :MDL}"},{"ref":"Money.Currency.html#mga/1","title":"Money.Currency.mga/1","type":"function","doc":"Convenience method to create a Money object for the Malagasy Ariary (MGA) currency. Example: iex&gt; Money.Currency.mga(100) %Money{amount: 100, currency: :MGA}"},{"ref":"Money.Currency.html#mkd/1","title":"Money.Currency.mkd/1","type":"function","doc":"Convenience method to create a Money object for the Denar (MKD) currency. Example: iex&gt; Money.Currency.mkd(100) %Money{amount: 100, currency: :MKD}"},{"ref":"Money.Currency.html#mmk/1","title":"Money.Currency.mmk/1","type":"function","doc":"Convenience method to create a Money object for the Kyat (MMK) currency. Example: iex&gt; Money.Currency.mmk(100) %Money{amount: 100, currency: :MMK}"},{"ref":"Money.Currency.html#mnt/1","title":"Money.Currency.mnt/1","type":"function","doc":"Convenience method to create a Money object for the Tugrik (MNT) currency. Example: iex&gt; Money.Currency.mnt(100) %Money{amount: 100, currency: :MNT}"},{"ref":"Money.Currency.html#mop/1","title":"Money.Currency.mop/1","type":"function","doc":"Convenience method to create a Money object for the Pataca (MOP) currency. Example: iex&gt; Money.Currency.mop(100) %Money{amount: 100, currency: :MOP}"},{"ref":"Money.Currency.html#mro/1","title":"Money.Currency.mro/1","type":"function","doc":"Convenience method to create a Money object for the Ouguiya (MRO) currency. Example: iex&gt; Money.Currency.mro(100) %Money{amount: 100, currency: :MRO}"},{"ref":"Money.Currency.html#mur/1","title":"Money.Currency.mur/1","type":"function","doc":"Convenience method to create a Money object for the Mauritius Rupee (MUR) currency. Example: iex&gt; Money.Currency.mur(100) %Money{amount: 100, currency: :MUR}"},{"ref":"Money.Currency.html#mvr/1","title":"Money.Currency.mvr/1","type":"function","doc":"Convenience method to create a Money object for the Rufiyaa (MVR) currency. Example: iex&gt; Money.Currency.mvr(100) %Money{amount: 100, currency: :MVR}"},{"ref":"Money.Currency.html#mwk/1","title":"Money.Currency.mwk/1","type":"function","doc":"Convenience method to create a Money object for the Kwacha (MWK) currency. Example: iex&gt; Money.Currency.mwk(100) %Money{amount: 100, currency: :MWK}"},{"ref":"Money.Currency.html#mxn/1","title":"Money.Currency.mxn/1","type":"function","doc":"Convenience method to create a Money object for the Mexican Peso (MXN) currency. Example: iex&gt; Money.Currency.mxn(100) %Money{amount: 100, currency: :MXN}"},{"ref":"Money.Currency.html#mxv/1","title":"Money.Currency.mxv/1","type":"function","doc":"Convenience method to create a Money object for the Mexican Peso Mexican Unidad de Inversion (UDI) (MXV) currency. Example: iex&gt; Money.Currency.mxv(100) %Money{amount: 100, currency: :MXV}"},{"ref":"Money.Currency.html#myr/1","title":"Money.Currency.myr/1","type":"function","doc":"Convenience method to create a Money object for the Malaysian Ringgit (MYR) currency. Example: iex&gt; Money.Currency.myr(100) %Money{amount: 100, currency: :MYR}"},{"ref":"Money.Currency.html#mzn/1","title":"Money.Currency.mzn/1","type":"function","doc":"Convenience method to create a Money object for the Metical (MZN) currency. Example: iex&gt; Money.Currency.mzn(100) %Money{amount: 100, currency: :MZN}"},{"ref":"Money.Currency.html#nad/1","title":"Money.Currency.nad/1","type":"function","doc":"Convenience method to create a Money object for the Rand Namibia Dollar (NAD) currency. Example: iex&gt; Money.Currency.nad(100) %Money{amount: 100, currency: :NAD}"},{"ref":"Money.Currency.html#name/1","title":"Money.Currency.name/1","type":"function","doc":"Returns the name of the currency or nil if it doesn’t exist. Example: iex&gt; Money.Currency.name(:USD) &quot;US Dollar&quot; iex&gt; Money.Currency.name(:WRONG) nil"},{"ref":"Money.Currency.html#name!/1","title":"Money.Currency.name!/1","type":"function","doc":"Returns the name of the currency. An ArgumentError is raised if the currency doesn’t exist. Example: iex&gt; Money.Currency.name!(:USD) &quot;US Dollar&quot; iex&gt; Money.Currency.name!(:WRONG) ** (ArgumentError) currency WRONG doesn’t exist"},{"ref":"Money.Currency.html#ngn/1","title":"Money.Currency.ngn/1","type":"function","doc":"Convenience method to create a Money object for the Naira (NGN) currency. Example: iex&gt; Money.Currency.ngn(100) %Money{amount: 100, currency: :NGN}"},{"ref":"Money.Currency.html#nio/1","title":"Money.Currency.nio/1","type":"function","doc":"Convenience method to create a Money object for the Cordoba Oro (NIO) currency. Example: iex&gt; Money.Currency.nio(100) %Money{amount: 100, currency: :NIO}"},{"ref":"Money.Currency.html#nok/1","title":"Money.Currency.nok/1","type":"function","doc":"Convenience method to create a Money object for the Norwegian Krone (NOK) currency. Example: iex&gt; Money.Currency.nok(100) %Money{amount: 100, currency: :NOK}"},{"ref":"Money.Currency.html#npr/1","title":"Money.Currency.npr/1","type":"function","doc":"Convenience method to create a Money object for the Nepalese Rupee (NPR) currency. Example: iex&gt; Money.Currency.npr(100) %Money{amount: 100, currency: :NPR}"},{"ref":"Money.Currency.html#nzd/1","title":"Money.Currency.nzd/1","type":"function","doc":"Convenience method to create a Money object for the New Zealand Dollar (NZD) currency. Example: iex&gt; Money.Currency.nzd(100) %Money{amount: 100, currency: :NZD}"},{"ref":"Money.Currency.html#omr/1","title":"Money.Currency.omr/1","type":"function","doc":"Convenience method to create a Money object for the Rial Omani (OMR) currency. Example: iex&gt; Money.Currency.omr(100) %Money{amount: 100, currency: :OMR}"},{"ref":"Money.Currency.html#pab/1","title":"Money.Currency.pab/1","type":"function","doc":"Convenience method to create a Money object for the Balboa US Dollar (PAB) currency. Example: iex&gt; Money.Currency.pab(100) %Money{amount: 100, currency: :PAB}"},{"ref":"Money.Currency.html#pen/1","title":"Money.Currency.pen/1","type":"function","doc":"Convenience method to create a Money object for the Nuevo Sol (PEN) currency. Example: iex&gt; Money.Currency.pen(100) %Money{amount: 100, currency: :PEN}"},{"ref":"Money.Currency.html#pgk/1","title":"Money.Currency.pgk/1","type":"function","doc":"Convenience method to create a Money object for the Kina (PGK) currency. Example: iex&gt; Money.Currency.pgk(100) %Money{amount: 100, currency: :PGK}"},{"ref":"Money.Currency.html#php/1","title":"Money.Currency.php/1","type":"function","doc":"Convenience method to create a Money object for the Philippine Peso (PHP) currency. Example: iex&gt; Money.Currency.php(100) %Money{amount: 100, currency: :PHP}"},{"ref":"Money.Currency.html#pkr/1","title":"Money.Currency.pkr/1","type":"function","doc":"Convenience method to create a Money object for the Pakistan Rupee (PKR) currency. Example: iex&gt; Money.Currency.pkr(100) %Money{amount: 100, currency: :PKR}"},{"ref":"Money.Currency.html#pln/1","title":"Money.Currency.pln/1","type":"function","doc":"Convenience method to create a Money object for the Zloty (PLN) currency. Example: iex&gt; Money.Currency.pln(100) %Money{amount: 100, currency: :PLN}"},{"ref":"Money.Currency.html#pyg/1","title":"Money.Currency.pyg/1","type":"function","doc":"Convenience method to create a Money object for the Guarani (PYG) currency. Example: iex&gt; Money.Currency.pyg(100) %Money{amount: 100, currency: :PYG}"},{"ref":"Money.Currency.html#qar/1","title":"Money.Currency.qar/1","type":"function","doc":"Convenience method to create a Money object for the Qatari Rial (QAR) currency. Example: iex&gt; Money.Currency.qar(100) %Money{amount: 100, currency: :QAR}"},{"ref":"Money.Currency.html#ron/1","title":"Money.Currency.ron/1","type":"function","doc":"Convenience method to create a Money object for the New Leu (RON) currency. Example: iex&gt; Money.Currency.ron(100) %Money{amount: 100, currency: :RON}"},{"ref":"Money.Currency.html#rsd/1","title":"Money.Currency.rsd/1","type":"function","doc":"Convenience method to create a Money object for the Serbian Dinar (RSD) currency. Example: iex&gt; Money.Currency.rsd(100) %Money{amount: 100, currency: :RSD}"},{"ref":"Money.Currency.html#rub/1","title":"Money.Currency.rub/1","type":"function","doc":"Convenience method to create a Money object for the Russian Ruble (RUB) currency. Example: iex&gt; Money.Currency.rub(100) %Money{amount: 100, currency: :RUB}"},{"ref":"Money.Currency.html#rwf/1","title":"Money.Currency.rwf/1","type":"function","doc":"Convenience method to create a Money object for the Rwanda Franc (RWF) currency. Example: iex&gt; Money.Currency.rwf(100) %Money{amount: 100, currency: :RWF}"},{"ref":"Money.Currency.html#sar/1","title":"Money.Currency.sar/1","type":"function","doc":"Convenience method to create a Money object for the Saudi Riyal (SAR) currency. Example: iex&gt; Money.Currency.sar(100) %Money{amount: 100, currency: :SAR}"},{"ref":"Money.Currency.html#sbd/1","title":"Money.Currency.sbd/1","type":"function","doc":"Convenience method to create a Money object for the Solomon Islands Dollar (SBD) currency. Example: iex&gt; Money.Currency.sbd(100) %Money{amount: 100, currency: :SBD}"},{"ref":"Money.Currency.html#scr/1","title":"Money.Currency.scr/1","type":"function","doc":"Convenience method to create a Money object for the Seychelles Rupee (SCR) currency. Example: iex&gt; Money.Currency.scr(100) %Money{amount: 100, currency: :SCR}"},{"ref":"Money.Currency.html#sdg/1","title":"Money.Currency.sdg/1","type":"function","doc":"Convenience method to create a Money object for the Sudanese Pound (SDG) currency. Example: iex&gt; Money.Currency.sdg(100) %Money{amount: 100, currency: :SDG}"},{"ref":"Money.Currency.html#sek/1","title":"Money.Currency.sek/1","type":"function","doc":"Convenience method to create a Money object for the Swedish Krona (SEK) currency. Example: iex&gt; Money.Currency.sek(100) %Money{amount: 100, currency: :SEK}"},{"ref":"Money.Currency.html#sgd/1","title":"Money.Currency.sgd/1","type":"function","doc":"Convenience method to create a Money object for the Singapore Dollar (SGD) currency. Example: iex&gt; Money.Currency.sgd(100) %Money{amount: 100, currency: :SGD}"},{"ref":"Money.Currency.html#shp/1","title":"Money.Currency.shp/1","type":"function","doc":"Convenience method to create a Money object for the Saint Helena Pound (SHP) currency. Example: iex&gt; Money.Currency.shp(100) %Money{amount: 100, currency: :SHP}"},{"ref":"Money.Currency.html#sll/1","title":"Money.Currency.sll/1","type":"function","doc":"Convenience method to create a Money object for the Leone (SLL) currency. Example: iex&gt; Money.Currency.sll(100) %Money{amount: 100, currency: :SLL}"},{"ref":"Money.Currency.html#sos/1","title":"Money.Currency.sos/1","type":"function","doc":"Convenience method to create a Money object for the Somali Shilling (SOS) currency. Example: iex&gt; Money.Currency.sos(100) %Money{amount: 100, currency: :SOS}"},{"ref":"Money.Currency.html#srd/1","title":"Money.Currency.srd/1","type":"function","doc":"Convenience method to create a Money object for the Surinam Dollar (SRD) currency. Example: iex&gt; Money.Currency.srd(100) %Money{amount: 100, currency: :SRD}"},{"ref":"Money.Currency.html#std/1","title":"Money.Currency.std/1","type":"function","doc":"Convenience method to create a Money object for the Dobra (STD) currency. Example: iex&gt; Money.Currency.std(100) %Money{amount: 100, currency: :STD}"},{"ref":"Money.Currency.html#sub_units_count!/1","title":"Money.Currency.sub_units_count!/1","type":"function","doc":"Returns the sub_units_count of the currency. An ArgumentError is raised if the currency doesn’t exist. Example: iex&gt; Money.Currency.sub_units_count!(:USD) 100 iex&gt; Money.Currency.sub_units_count!(:JPY) 1 iex&gt; Money.Currency.sub_units_count!(:WRONG) ** (ArgumentError) currency WRONG doesn’t exist"},{"ref":"Money.Currency.html#svc/1","title":"Money.Currency.svc/1","type":"function","doc":"Convenience method to create a Money object for the El Salvador Colon US Dollar (SVC) currency. Example: iex&gt; Money.Currency.svc(100) %Money{amount: 100, currency: :SVC}"},{"ref":"Money.Currency.html#symbol/1","title":"Money.Currency.symbol/1","type":"function","doc":"Returns the symbol of the currency or nil if it doesn’t exist. Example: iex&gt; Money.Currency.symbol(:USD) &quot;$&quot; iex&gt; Money.Currency.symbol(:WRONG) nil"},{"ref":"Money.Currency.html#symbol!/1","title":"Money.Currency.symbol!/1","type":"function","doc":"Returns the symbol of the currency. An ArgumentError is raised if the currency doesn’t exist. Example: iex&gt; Money.Currency.symbol!(:USD) &quot;$&quot; iex&gt; Money.Currency.symbol!(:WRONG) ** (ArgumentError) currency WRONG doesn’t exist"},{"ref":"Money.Currency.html#syp/1","title":"Money.Currency.syp/1","type":"function","doc":"Convenience method to create a Money object for the Syrian Pound (SYP) currency. Example: iex&gt; Money.Currency.syp(100) %Money{amount: 100, currency: :SYP}"},{"ref":"Money.Currency.html#szl/1","title":"Money.Currency.szl/1","type":"function","doc":"Convenience method to create a Money object for the Lilangeni (SZL) currency. Example: iex&gt; Money.Currency.szl(100) %Money{amount: 100, currency: :SZL}"},{"ref":"Money.Currency.html#thb/1","title":"Money.Currency.thb/1","type":"function","doc":"Convenience method to create a Money object for the Baht (THB) currency. Example: iex&gt; Money.Currency.thb(100) %Money{amount: 100, currency: :THB}"},{"ref":"Money.Currency.html#tjs/1","title":"Money.Currency.tjs/1","type":"function","doc":"Convenience method to create a Money object for the Somoni (TJS) currency. Example: iex&gt; Money.Currency.tjs(100) %Money{amount: 100, currency: :TJS}"},{"ref":"Money.Currency.html#tmt/1","title":"Money.Currency.tmt/1","type":"function","doc":"Convenience method to create a Money object for the Manat (TMT) currency. Example: iex&gt; Money.Currency.tmt(100) %Money{amount: 100, currency: :TMT}"},{"ref":"Money.Currency.html#tnd/1","title":"Money.Currency.tnd/1","type":"function","doc":"Convenience method to create a Money object for the Tunisian Dinar (TND) currency. Example: iex&gt; Money.Currency.tnd(100) %Money{amount: 100, currency: :TND}"},{"ref":"Money.Currency.html#to_atom/1","title":"Money.Currency.to_atom/1","type":"function","doc":"Returns the atom representation of the currency key An ArgumentError is raised if the currency doesn’t exist. Example: iex&gt; Money.Currency.to_atom(&quot;usd&quot;) :USD iex&gt; Money.Currency.to_atom(:WRONG) ** (ArgumentError) currency WRONG doesn’t exist"},{"ref":"Money.Currency.html#top/1","title":"Money.Currency.top/1","type":"function","doc":"Convenience method to create a Money object for the Pa&#39;anga (TOP) currency. Example: iex&gt; Money.Currency.top(100) %Money{amount: 100, currency: :TOP}"},{"ref":"Money.Currency.html#try/1","title":"Money.Currency.try/1","type":"function","doc":"Convenience method to create a Money object for the Turkish Lira (TRY) currency. Example: iex&gt; Money.Currency.try(100) %Money{amount: 100, currency: :TRY}"},{"ref":"Money.Currency.html#ttd/1","title":"Money.Currency.ttd/1","type":"function","doc":"Convenience method to create a Money object for the Trinidad and Tobago Dollar (TTD) currency. Example: iex&gt; Money.Currency.ttd(100) %Money{amount: 100, currency: :TTD}"},{"ref":"Money.Currency.html#twd/1","title":"Money.Currency.twd/1","type":"function","doc":"Convenience method to create a Money object for the New Taiwan Dollar (TWD) currency. Example: iex&gt; Money.Currency.twd(100) %Money{amount: 100, currency: :TWD}"},{"ref":"Money.Currency.html#tzs/1","title":"Money.Currency.tzs/1","type":"function","doc":"Convenience method to create a Money object for the Tanzanian Shilling (TZS) currency. Example: iex&gt; Money.Currency.tzs(100) %Money{amount: 100, currency: :TZS}"},{"ref":"Money.Currency.html#uah/1","title":"Money.Currency.uah/1","type":"function","doc":"Convenience method to create a Money object for the Hryvnia (UAH) currency. Example: iex&gt; Money.Currency.uah(100) %Money{amount: 100, currency: :UAH}"},{"ref":"Money.Currency.html#ugx/1","title":"Money.Currency.ugx/1","type":"function","doc":"Convenience method to create a Money object for the Uganda Shilling (UGX) currency. Example: iex&gt; Money.Currency.ugx(100) %Money{amount: 100, currency: :UGX}"},{"ref":"Money.Currency.html#usd/1","title":"Money.Currency.usd/1","type":"function","doc":"Convenience method to create a Money object for the US Dollar (USD) currency. Example: iex&gt; Money.Currency.usd(100) %Money{amount: 100, currency: :USD}"},{"ref":"Money.Currency.html#uyi/1","title":"Money.Currency.uyi/1","type":"function","doc":"Convenience method to create a Money object for the Peso Uruguayo Uruguay Peso en Unidades Indexadas (UYI) currency. Example: iex&gt; Money.Currency.uyi(100) %Money{amount: 100, currency: :UYI}"},{"ref":"Money.Currency.html#uyu/1","title":"Money.Currency.uyu/1","type":"function","doc":"Convenience method to create a Money object for the Peso Uruguayo Uruguay Peso en Unidades Indexadas (UYU) currency. Example: iex&gt; Money.Currency.uyu(100) %Money{amount: 100, currency: :UYU}"},{"ref":"Money.Currency.html#uzs/1","title":"Money.Currency.uzs/1","type":"function","doc":"Convenience method to create a Money object for the Uzbekistan Sum (UZS) currency. Example: iex&gt; Money.Currency.uzs(100) %Money{amount: 100, currency: :UZS}"},{"ref":"Money.Currency.html#vef/1","title":"Money.Currency.vef/1","type":"function","doc":"Convenience method to create a Money object for the Bolivar Fuerte (VEF) currency. Example: iex&gt; Money.Currency.vef(100) %Money{amount: 100, currency: :VEF}"},{"ref":"Money.Currency.html#vnd/1","title":"Money.Currency.vnd/1","type":"function","doc":"Convenience method to create a Money object for the Dong (VND) currency. Example: iex&gt; Money.Currency.vnd(100) %Money{amount: 100, currency: :VND}"},{"ref":"Money.Currency.html#vuv/1","title":"Money.Currency.vuv/1","type":"function","doc":"Convenience method to create a Money object for the Vatu (VUV) currency. Example: iex&gt; Money.Currency.vuv(100) %Money{amount: 100, currency: :VUV}"},{"ref":"Money.Currency.html#wst/1","title":"Money.Currency.wst/1","type":"function","doc":"Convenience method to create a Money object for the Tala (WST) currency. Example: iex&gt; Money.Currency.wst(100) %Money{amount: 100, currency: :WST}"},{"ref":"Money.Currency.html#xaf/1","title":"Money.Currency.xaf/1","type":"function","doc":"Convenience method to create a Money object for the CFA Franc BEAC (XAF) currency. Example: iex&gt; Money.Currency.xaf(100) %Money{amount: 100, currency: :XAF}"},{"ref":"Money.Currency.html#xag/1","title":"Money.Currency.xag/1","type":"function","doc":"Convenience method to create a Money object for the Silver (XAG) currency. Example: iex&gt; Money.Currency.xag(100) %Money{amount: 100, currency: :XAG}"},{"ref":"Money.Currency.html#xau/1","title":"Money.Currency.xau/1","type":"function","doc":"Convenience method to create a Money object for the Gold (XAU) currency. Example: iex&gt; Money.Currency.xau(100) %Money{amount: 100, currency: :XAU}"},{"ref":"Money.Currency.html#xba/1","title":"Money.Currency.xba/1","type":"function","doc":"Convenience method to create a Money object for the Bond Markets Units European Composite Unit (EURCO) (XBA) currency. Example: iex&gt; Money.Currency.xba(100) %Money{amount: 100, currency: :XBA}"},{"ref":"Money.Currency.html#xbb/1","title":"Money.Currency.xbb/1","type":"function","doc":"Convenience method to create a Money object for the European Monetary Unit (E.M.U.-6) (XBB) currency. Example: iex&gt; Money.Currency.xbb(100) %Money{amount: 100, currency: :XBB}"},{"ref":"Money.Currency.html#xbc/1","title":"Money.Currency.xbc/1","type":"function","doc":"Convenience method to create a Money object for the European Unit of Account 9(E.U.A.-9) (XBC) currency. Example: iex&gt; Money.Currency.xbc(100) %Money{amount: 100, currency: :XBC}"},{"ref":"Money.Currency.html#xbd/1","title":"Money.Currency.xbd/1","type":"function","doc":"Convenience method to create a Money object for the European Unit of Account 17(E.U.A.-17) (XBD) currency. Example: iex&gt; Money.Currency.xbd(100) %Money{amount: 100, currency: :XBD}"},{"ref":"Money.Currency.html#xcd/1","title":"Money.Currency.xcd/1","type":"function","doc":"Convenience method to create a Money object for the East Caribbean Dollar (XCD) currency. Example: iex&gt; Money.Currency.xcd(100) %Money{amount: 100, currency: :XCD}"},{"ref":"Money.Currency.html#xdr/1","title":"Money.Currency.xdr/1","type":"function","doc":"Convenience method to create a Money object for the SDR (XDR) currency. Example: iex&gt; Money.Currency.xdr(100) %Money{amount: 100, currency: :XDR}"},{"ref":"Money.Currency.html#xfu/1","title":"Money.Currency.xfu/1","type":"function","doc":"Convenience method to create a Money object for the UIC-Franc (XFU) currency. Example: iex&gt; Money.Currency.xfu(100) %Money{amount: 100, currency: :XFU}"},{"ref":"Money.Currency.html#xof/1","title":"Money.Currency.xof/1","type":"function","doc":"Convenience method to create a Money object for the CFA Franc BCEAO (XOF) currency. Example: iex&gt; Money.Currency.xof(100) %Money{amount: 100, currency: :XOF}"},{"ref":"Money.Currency.html#xpd/1","title":"Money.Currency.xpd/1","type":"function","doc":"Convenience method to create a Money object for the Palladium (XPD) currency. Example: iex&gt; Money.Currency.xpd(100) %Money{amount: 100, currency: :XPD}"},{"ref":"Money.Currency.html#xpf/1","title":"Money.Currency.xpf/1","type":"function","doc":"Convenience method to create a Money object for the CFP Franc (XPF) currency. Example: iex&gt; Money.Currency.xpf(100) %Money{amount: 100, currency: :XPF}"},{"ref":"Money.Currency.html#xpt/1","title":"Money.Currency.xpt/1","type":"function","doc":"Convenience method to create a Money object for the Platinum (XPT) currency. Example: iex&gt; Money.Currency.xpt(100) %Money{amount: 100, currency: :XPT}"},{"ref":"Money.Currency.html#xts/1","title":"Money.Currency.xts/1","type":"function","doc":"Convenience method to create a Money object for the Codes specifically reserved for testing purposes (XTS) currency. Example: iex&gt; Money.Currency.xts(100) %Money{amount: 100, currency: :XTS}"},{"ref":"Money.Currency.html#yer/1","title":"Money.Currency.yer/1","type":"function","doc":"Convenience method to create a Money object for the Yemeni Rial (YER) currency. Example: iex&gt; Money.Currency.yer(100) %Money{amount: 100, currency: :YER}"},{"ref":"Money.Currency.html#zar/1","title":"Money.Currency.zar/1","type":"function","doc":"Convenience method to create a Money object for the Rand (ZAR) currency. Example: iex&gt; Money.Currency.zar(100) %Money{amount: 100, currency: :ZAR}"},{"ref":"Money.Currency.html#zmk/1","title":"Money.Currency.zmk/1","type":"function","doc":"Convenience method to create a Money object for the Zambian Kwacha (ZMK) currency. Example: iex&gt; Money.Currency.zmk(100) %Money{amount: 100, currency: :ZMK}"},{"ref":"Money.Currency.html#zwl/1","title":"Money.Currency.zwl/1","type":"function","doc":"Convenience method to create a Money object for the Zimbabwe Dollar (ZWL) currency. Example: iex&gt; Money.Currency.zwl(100) %Money{amount: 100, currency: :ZWL}"},{"ref":"Money.Currency.Ecto.Type.html","title":"Money.Currency.Ecto.Type","type":"module","doc":"Provides a type for Ecto to store a currency. The underlying data type is a string. Migration Example create table(:my_table) do add :currency, :string end Schema Example schema &quot;my_table&quot; do field :currency, Money.Currency.Ecto.Type end"},{"ref":"Money.Currency.Ecto.Type.html#cast/1","title":"Money.Currency.Ecto.Type.cast/1","type":"function","doc":"Casts the given input to the custom type. This callback is called on external input and can return any type, as long as the dump/1 function is able to convert the returned value into an Ecto native type. There are two situations where this callback is called: When casting values by Ecto.Changeset When passing arguments to Ecto.Query When returning {:error, keyword()}, the returned keyword list will be preserved in the changeset errors, similar to Changeset.add_error/4. Passing a :message key, will override the default message. It is not possible to override the :type key. For {:array, CustomType} or {:map, CustomType} the returned keyword list will be erased and the default error will be shown. Callback implementation for Ecto.Type.cast/1."},{"ref":"Money.Currency.Ecto.Type.html#dump/1","title":"Money.Currency.Ecto.Type.dump/1","type":"function","doc":"Dumps the given term into an Ecto native type. This callback is called with any term that was stored in the struct and it needs to validate them and convert it to an Ecto native type. Callback implementation for Ecto.Type.dump/1."},{"ref":"Money.Currency.Ecto.Type.html#load/1","title":"Money.Currency.Ecto.Type.load/1","type":"function","doc":"Loads the given term into a custom type. This callback is called when loading data from the database and receives an Ecto native type. It can return any type, as long as the dump/1 function is able to convert the returned value back into an Ecto native type. Callback implementation for Ecto.Type.load/1."},{"ref":"Money.Currency.Ecto.Type.html#type/0","title":"Money.Currency.Ecto.Type.type/0","type":"function","doc":"Returns the underlying schema type for the custom type. For example, if you want to provide your own date structures, the type function should return :date. Note this function is not required to return Ecto primitive types, the type is only required to be known by the adapter. Callback implementation for Ecto.Type.type/0."},{"ref":"Money.Ecto.Amount.Type.html","title":"Money.Ecto.Amount.Type","type":"module","doc":"Provides a type for Ecto to store a amount. The underlying data type should be an integer. Migration Example create table(:my_table) do add :amount, :integer end Schema Example schema &quot;my_table&quot; do field :amount, Money.Ecto.Amount.Type end"},{"ref":"Money.Ecto.Amount.Type.html#cast/1","title":"Money.Ecto.Amount.Type.cast/1","type":"function","doc":"Casts the given input to the custom type. This callback is called on external input and can return any type, as long as the dump/1 function is able to convert the returned value into an Ecto native type. There are two situations where this callback is called: When casting values by Ecto.Changeset When passing arguments to Ecto.Query When returning {:error, keyword()}, the returned keyword list will be preserved in the changeset errors, similar to Changeset.add_error/4. Passing a :message key, will override the default message. It is not possible to override the :type key. For {:array, CustomType} or {:map, CustomType} the returned keyword list will be erased and the default error will be shown. Callback implementation for Ecto.Type.cast/1."},{"ref":"Money.Ecto.Amount.Type.html#dump/1","title":"Money.Ecto.Amount.Type.dump/1","type":"function","doc":"Dumps the given term into an Ecto native type. This callback is called with any term that was stored in the struct and it needs to validate them and convert it to an Ecto native type. Callback implementation for Ecto.Type.dump/1."},{"ref":"Money.Ecto.Amount.Type.html#load/1","title":"Money.Ecto.Amount.Type.load/1","type":"function","doc":"Loads the given term into a custom type. This callback is called when loading data from the database and receives an Ecto native type. It can return any type, as long as the dump/1 function is able to convert the returned value back into an Ecto native type. Callback implementation for Ecto.Type.load/1."},{"ref":"Money.Ecto.Amount.Type.html#type/0","title":"Money.Ecto.Amount.Type.type/0","type":"function","doc":"Returns the underlying schema type for the custom type. For example, if you want to provide your own date structures, the type function should return :date. Note this function is not required to return Ecto primitive types, the type is only required to be known by the adapter. Callback implementation for Ecto.Type.type/0."},{"ref":"Money.Ecto.Composite.Type.html","title":"Money.Ecto.Composite.Type","type":"module","doc":"Provides a type for Ecto to store a multi-currency price. The underlying data type should be an user-defined Postgres composite type :money_with_currency. Migration Example execute &quot;CREATE TYPE public.money_with_currency AS (amount integer, currency char(3))&quot; create table(:my_table) do add :price, :money_with_currency end Schema Example schema &quot;my_table&quot; do field :price, Money.Ecto.Composite.Type end"},{"ref":"Money.Ecto.Composite.Type.html#cast/1","title":"Money.Ecto.Composite.Type.cast/1","type":"function","doc":"Casts the given input to the custom type. This callback is called on external input and can return any type, as long as the dump/1 function is able to convert the returned value into an Ecto native type. There are two situations where this callback is called: When casting values by Ecto.Changeset When passing arguments to Ecto.Query When returning {:error, keyword()}, the returned keyword list will be preserved in the changeset errors, similar to Changeset.add_error/4. Passing a :message key, will override the default message. It is not possible to override the :type key. For {:array, CustomType} or {:map, CustomType} the returned keyword list will be erased and the default error will be shown. Callback implementation for Ecto.Type.cast/1."},{"ref":"Money.Ecto.Composite.Type.html#dump/1","title":"Money.Ecto.Composite.Type.dump/1","type":"function","doc":"Dumps the given term into an Ecto native type. This callback is called with any term that was stored in the struct and it needs to validate them and convert it to an Ecto native type. Callback implementation for Ecto.Type.dump/1."},{"ref":"Money.Ecto.Composite.Type.html#load/1","title":"Money.Ecto.Composite.Type.load/1","type":"function","doc":"Loads the given term into a custom type. This callback is called when loading data from the database and receives an Ecto native type. It can return any type, as long as the dump/1 function is able to convert the returned value back into an Ecto native type. Callback implementation for Ecto.Type.load/1."},{"ref":"Money.Ecto.Composite.Type.html#type/0","title":"Money.Ecto.Composite.Type.type/0","type":"function","doc":"Returns the underlying schema type for the custom type. For example, if you want to provide your own date structures, the type function should return :date. Note this function is not required to return Ecto primitive types, the type is only required to be known by the adapter. Callback implementation for Ecto.Type.type/0."},{"ref":"Money.Ecto.Currency.Type.html","title":"Money.Ecto.Currency.Type","type":"module","doc":"Provides a type for Ecto to store a currency. The underlying data type is a string. Migration Example create table(:my_table) do add :currency, :varchar, size: 3 end Schema Example schema &quot;my_table&quot; do field :currency, Money.Ecto.Currency.Type end"},{"ref":"Money.Ecto.Currency.Type.html#cast/1","title":"Money.Ecto.Currency.Type.cast/1","type":"function","doc":"Casts the given input to the custom type. This callback is called on external input and can return any type, as long as the dump/1 function is able to convert the returned value into an Ecto native type. There are two situations where this callback is called: When casting values by Ecto.Changeset When passing arguments to Ecto.Query When returning {:error, keyword()}, the returned keyword list will be preserved in the changeset errors, similar to Changeset.add_error/4. Passing a :message key, will override the default message. It is not possible to override the :type key. For {:array, CustomType} or {:map, CustomType} the returned keyword list will be erased and the default error will be shown. Callback implementation for Ecto.Type.cast/1."},{"ref":"Money.Ecto.Currency.Type.html#dump/1","title":"Money.Ecto.Currency.Type.dump/1","type":"function","doc":"Dumps the given term into an Ecto native type. This callback is called with any term that was stored in the struct and it needs to validate them and convert it to an Ecto native type. Callback implementation for Ecto.Type.dump/1."},{"ref":"Money.Ecto.Currency.Type.html#load/1","title":"Money.Ecto.Currency.Type.load/1","type":"function","doc":"Loads the given term into a custom type. This callback is called when loading data from the database and receives an Ecto native type. It can return any type, as long as the dump/1 function is able to convert the returned value back into an Ecto native type. Callback implementation for Ecto.Type.load/1."},{"ref":"Money.Ecto.Currency.Type.html#type/0","title":"Money.Ecto.Currency.Type.type/0","type":"function","doc":"Returns the underlying schema type for the custom type. For example, if you want to provide your own date structures, the type function should return :date. Note this function is not required to return Ecto primitive types, the type is only required to be known by the adapter. Callback implementation for Ecto.Type.type/0."},{"ref":"Money.Ecto.Map.Type.html","title":"Money.Ecto.Map.Type","type":"module","doc":"Provides a type for Ecto to store a multi-currency price. The underlying data type should be a map(JSON). Suitable for databases that do not support composite types, but support JSON (e.g. MySQL). Migration Example reate table(:my_table) do add :price, :map end Schema Example schema &quot;my_table&quot; do field :price, Money.Ecto.Map.Type end"},{"ref":"Money.Ecto.Map.Type.html#cast/1","title":"Money.Ecto.Map.Type.cast/1","type":"function","doc":"Casts the given input to the custom type. This callback is called on external input and can return any type, as long as the dump/1 function is able to convert the returned value into an Ecto native type. There are two situations where this callback is called: When casting values by Ecto.Changeset When passing arguments to Ecto.Query When returning {:error, keyword()}, the returned keyword list will be preserved in the changeset errors, similar to Changeset.add_error/4. Passing a :message key, will override the default message. It is not possible to override the :type key. For {:array, CustomType} or {:map, CustomType} the returned keyword list will be erased and the default error will be shown. Callback implementation for Ecto.Type.cast/1."},{"ref":"Money.Ecto.Map.Type.html#dump/1","title":"Money.Ecto.Map.Type.dump/1","type":"function","doc":"Dumps the given term into an Ecto native type. This callback is called with any term that was stored in the struct and it needs to validate them and convert it to an Ecto native type. Callback implementation for Ecto.Type.dump/1."},{"ref":"Money.Ecto.Map.Type.html#load/1","title":"Money.Ecto.Map.Type.load/1","type":"function","doc":"Loads the given term into a custom type. This callback is called when loading data from the database and receives an Ecto native type. It can return any type, as long as the dump/1 function is able to convert the returned value back into an Ecto native type. Callback implementation for Ecto.Type.load/1."},{"ref":"Money.Ecto.Map.Type.html#type/0","title":"Money.Ecto.Map.Type.type/0","type":"function","doc":"Returns the underlying schema type for the custom type. For example, if you want to provide your own date structures, the type function should return :date. Note this function is not required to return Ecto primitive types, the type is only required to be known by the adapter. Callback implementation for Ecto.Type.type/0."},{"ref":"Money.Ecto.Type.html","title":"Money.Ecto.Type","type":"module","doc":"WARNING: this module is deprecated. Use Money.Ecto.Amount.Type module instead. Provides a type for Ecto usage. The underlying data type should be an integer. This type expects you to use a single currency. The currency must be defined in your configuration. config :money, default_currency: :GBP Migration Example create table(:my_table) do add :amount, :integer end Schema Example schema &quot;my_table&quot; do field :amount, Money.Ecto.Type end"},{"ref":"Money.Ecto.Type.html#cast/1","title":"Money.Ecto.Type.cast/1","type":"function","doc":"Casts the given input to the custom type. This callback is called on external input and can return any type, as long as the dump/1 function is able to convert the returned value into an Ecto native type. There are two situations where this callback is called: When casting values by Ecto.Changeset When passing arguments to Ecto.Query When returning {:error, keyword()}, the returned keyword list will be preserved in the changeset errors, similar to Changeset.add_error/4. Passing a :message key, will override the default message. It is not possible to override the :type key. For {:array, CustomType} or {:map, CustomType} the returned keyword list will be erased and the default error will be shown. Callback implementation for Ecto.Type.cast/1."},{"ref":"Money.Ecto.Type.html#dump/1","title":"Money.Ecto.Type.dump/1","type":"function","doc":"Dumps the given term into an Ecto native type. This callback is called with any term that was stored in the struct and it needs to validate them and convert it to an Ecto native type. Callback implementation for Ecto.Type.dump/1."},{"ref":"Money.Ecto.Type.html#load/1","title":"Money.Ecto.Type.load/1","type":"function","doc":"Loads the given term into a custom type. This callback is called when loading data from the database and receives an Ecto native type. It can return any type, as long as the dump/1 function is able to convert the returned value back into an Ecto native type. Callback implementation for Ecto.Type.load/1."},{"ref":"Money.Ecto.Type.html#type/0","title":"Money.Ecto.Type.type/0","type":"function","doc":"Returns the underlying schema type for the custom type. For example, if you want to provide your own date structures, the type function should return :date. Note this function is not required to return Ecto primitive types, the type is only required to be known by the adapter. Callback implementation for Ecto.Type.type/0."},{"ref":"readme.html","title":"Money","type":"extras","doc":"Money Elixir library for working with Money safer, easier, and fun, is an interpretation of the Fowler&#39;s Money pattern in fun.prog. &quot;If I had a dime for every time I&#39;ve seen someone use FLOAT to store currency, I&#39;d have $999.997634&quot; -- Bill Karwin In short: You shouldn&#39;t represent monetary values by a float. Wherever you need to represent money, use Money. Documentation can be found at https://hexdocs.pm/money/Money.html on HexDocs"},{"ref":"readme.html#usage","title":"Money - USAGE","type":"extras","doc":"five_eur = Money.new(500, :EUR) # %Money{amount: 500, currency: :EUR} ten_eur = Money.add(five_eur, five_eur) # %Money{amount: 10_00, currency: :EUR} hundred_eur = Money.multiply(ten_eur, 10) # %Money{amount: 100_00, currency: :EUR} ninety_nine_eur = Money.subtract(hundred_eur, 100) # %Money{amount: 99_00, currency: :EUR} shares = Money.divide(ninety_nine_eur, 2) # [%Money{amount: 4950, currency: :EUR}, %Money{amount: 4950, currency: :EUR}] Money.equals?(five_eur, Money.new(500, :EUR)) # true Money.zero?(five_eur); # false Money.positive?(five_eur); # true Money.Currency.symbol(:USD) # $ Money.Currency.symbol(Money.new(500, :AFN)) # ؋ Money.Currency.name(Money.new(500, :AFN)) # Afghani Money.to_string(Money.new(500, :CNY)) # ¥ 5.00 Money.to_string(Money.new(1_234_56, :EUR), separator: &quot;.&quot;, delimiter: &quot;,&quot;, symbol: false) &quot;1.234,56&quot; Money.to_string(Money.new(1_234_56, :USD), fractional_unit: false) # &quot;$1,234&quot; Money.to_string(Money.new(1_234_50, :USD), strip_insignificant_zeros: true) # &quot;$1,234.5&quot; Serialization to database with single currency Bring Money to your Ecto project. The underlying database type is integer Set a default currency in config.ex: config :money, default_currency: :USD Create migration with integer type: create table(:jobs) do add :amount, :integer end Create schema using the Money.Ecto.Amount.Type Ecto type (don&#39;t forget run mix ecto.migrate): schema &quot;jobs&quot; do field :amount, Money.Ecto.Amount.Type end Save to the database: iex(1)&gt; Repo.insert %Job{amount: Money.new(100, :USD)} [debug] QUERY OK db=90.7ms queue=0.1ms INSERT INTO &quot;jobs&quot; (&quot;amount&quot;,&quot;inserted_at&quot;,&quot;updated_at&quot;) VALUES ($1,$2,$3) RETURNING &quot;id&quot; [100, {{2019, 2, 12}, {7, 29, 8, 589489}}, {{2019, 2, 12}, {7, 29, 8, 593185}}] {:ok, %MoneyTest.Offers.Job{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;jobs&quot;&gt;, amount: %Money{amount: 100, currency: :USD}, id: 1, inserted_at: ~N[2019-02-12 07:29:08.589489], updated_at: ~N[2019-02-12 07:29:08.593185] }} Get from the database: iex(2)&gt; Repo.one(Job, limit: 1) [debug] QUERY OK source=&quot;jobs&quot; db=1.8ms SELECT j0.&quot;id&quot;, j0.&quot;amount&quot;, j0.&quot;inserted_at&quot;, j0.&quot;updated_at&quot; FROM &quot;jobs&quot; AS j0 [] %MoneyTest.Offers.Job{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;jobs&quot;&gt;, amount: %Money{amount: 100, currency: :USD}, id: 1, inserted_at: ~N[2019-02-12 07:29:08.589489], updated_at: ~N[2019-02-12 07:29:08.593185] } Serialization to PostgreSQL with multiple currency Money.Ecto.Composite.Type Ecto type represents serialization of Money.t to PostgreSQL Composite Types with saving currency. Create migration with custom type: def up do execute &quot;&quot;&quot; CREATE TYPE public.money_with_currency AS (amount integer, currency char(3)) &quot;&quot;&quot; end def down do execute &quot;&quot;&quot; DROP TYPE public.money_with_currency &quot;&quot;&quot; end Then use created custom type(money_with_currency) for money field: def change do alter table(:jobs) do add :price, :money_with_currency end end` Create schema using the Money.Ecto.Composite.Type Ecto type (don&#39;t forget run mix ecto.migrate): schema &quot;jobs&quot; do field :price, Money.Ecto.Composite.Type end Save to the database: iex(1)&gt; Repo.insert %Job{price: Money.new(100, :JPY)} [debug] QUERY OK db=7.7ms INSERT INTO &quot;jobs&quot; (&quot;price&quot;,&quot;inserted_at&quot;,&quot;updated_at&quot;) VALUES ($1,$2,$3) RETURNING &quot;id&quot; [{100, &quot;JPY&quot;}, {{2019, 2, 12}, {8, 7, 44, 729114}}, {{2019, 2, 12}, {8, 7, 44, 729124}}] {:ok, %MoneyTest.Offers.Job{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;jobs&quot;&gt;, id: 6, inserted_at: ~N[2019-02-12 08:07:44.729114], price: %Money{amount: 100, currency: :JPY}, updated_at: ~N[2019-02-12 08:07:44.729124] }} Get from the database: iex(2)&gt; Repo.one(Job, limit: 1) [debug] QUERY OK source=&quot;jobs&quot; db=1.4ms SELECT j0.&quot;id&quot;, j0.&quot;price&quot;, j0.&quot;inserted_at&quot;, j0.&quot;updated_at&quot; FROM &quot;jobs&quot; AS j0 [] %MoneyTest.Offers.Job{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;jobs&quot;&gt;, id: 6, inserted_at: ~N[2019-02-12 08:07:44.729114], price: %Money{amount: 100, currency: :JPY}, updated_at: ~N[2019-02-12 08:07:44.729124] } Serialization to database (JSON) with multiple currency Money.Ecto.Map.Type Ecto type represents serialization of Money.t to map(JSON) with saving currency. Create migration with map type: def change do alter table(:jobs) do add :price, :map end end Create schema using the Money.Ecto.Map.Type Ecto type (don&#39;t forget run mix ecto.migrate): schema &quot;jobs&quot; do field :price, Money.Ecto.Map.Type end Save to the database: iex(1)&gt; Repo.insert %Job{price: Money.new(100, :JPY)} [debug] QUERY OK db=4.6ms INSERT INTO &quot;jobs&quot; (&quot;price&quot;,&quot;inserted_at&quot;,&quot;updated_at&quot;) VALUES ($1,$2,$3) RETURNING &quot;id&quot; [%{&quot;amount&quot; =&gt; 100, &quot;currency&quot; =&gt; &quot;JPY&quot;}, {{2019, 2, 26}, {9, 40, 14, 381721}}, {{2019, 2, 26}, {9, 40, 14, 381730}}] {:ok, %MoneyTest.Offers.Job{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;jobs&quot;&gt;, id: 9, inserted_at: ~N[2019-02-26 09:40:14.381721], price: %Money{amount: 100, currency: :JPY}, updated_at: ~N[2019-02-26 09:40:14.381730] }} Get from the database: iex(8)&gt; Repo.one(Job, limit: 1) [debug] QUERY OK source=&quot;jobs&quot; db=2.0ms SELECT j0.&quot;id&quot;, j0.&quot;price&quot;, j0.&quot;inserted_at&quot;, j0.&quot;updated_at&quot; FROM &quot;jobs&quot; AS j0 [] %MoneyTest.Offers.Job{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;jobs&quot;&gt;, id: 10, inserted_at: ~N[2019-02-26 09:40:45.205076], price: %Money{amount: 100, currency: :JPY}, updated_at: ~N[2019-02-26 09:40:45.205084] } Money.Sigils # Sigils for Money import Money.Sigils iex&gt; ~M[1000]USD %Money{amount: 1000, currency: :USD} # If you have a default currency configured (e.g. to GBP), you can do iex&gt; ~M[1000] %Money{amount: 1000, currency: :GBP} Money.Currency # Currency convenience methods import Money.Currency, only: [usd: 1, eur: 1, afn: 1] iex&gt; usd(100_00) %Money{amount: 10000, currency: :USD} iex&gt; eur(100_00) %Money{amount: 10000, currency: :EUR} iex&gt; afn(100_00) %Money{amount: 10000, currency: :AFN} Money.Currency.symbol(:USD) # $ Money.Currency.symbol(afn(500)) # ؋ Money.Currency.name(afn(500)) # Afghani Money.Currency.get(:AFN) # %{name: &quot;Afghani&quot;, symbol: &quot;؋&quot;} Phoenix.HTML.Safe Bring Money to your Phoenix project. If you are using Phoenix, you can include money objects directly into your output and they will be correctly escaped. &lt;b&gt;&lt;%= Money.new(12345,67, :GBP) %&gt;&lt;/b&gt;"},{"ref":"readme.html#installation","title":"Money - INSTALLATION","type":"extras","doc":"Money comes with no required dependencies. Add the following to your mix.exs: def deps do [{:money, &quot;~&gt; 1.4&quot;}] end then run mix deps.get."},{"ref":"readme.html#configuration","title":"Money - CONFIGURATION","type":"extras","doc":"You can set a default currency and default formatting preferences as follows: config :money, default_currency: :EUR, separator: &quot;.&quot;, delimiter: &quot;,&quot;, symbol: false, symbol_on_right: false, symbol_space: false, fractional_unit: true, strip_insignificant_zeros: false Then you don’t have to specify the currency. iex&gt; amount = Money.new(1_234_50) %Money{amount: 123450, currency: :EUR} iex&gt; to_string(amount) &quot;1.234,50&quot; Here is another example of formatting money: iex&gt; amount = Money.new(1_234_50) %Money{amount: 123450, currency: :EUR} iex&gt; Money.to_string(amount, symbol: true, symbol_on_right: true, symbol_space: true) &quot;1.234,50 €&quot;"},{"ref":"readme.html#adding-your-own-currencies","title":"Money - Adding your own currencies","type":"extras","doc":"In some cases we can need to add not common currencies, like crypto currencies or others. In order to add your own currencies you have to add them in the config file following this format: config :money, custom_currencies: [ BTC: %{name: &quot;Bitcoin&quot;, symbol: &quot;₿&quot;, exponent: 2}, GCS: %{name: &quot;Galactic Credit Standard&quot;, symbol: &quot;gcs&quot;, exponent: 0} ]"},{"ref":"readme.html#license","title":"Money - LICENSE","type":"extras","doc":"MIT License please see the LICENSE file."},{"ref":"contributing.html","title":"Contribution Guidelines","type":"extras","doc":"Contribution Guidelines"},{"ref":"contributing.html#steps","title":"Contribution Guidelines - Steps","type":"extras","doc":"Fork the repo Make sure everything is working: mix test Create your feature branch (git checkout -b my-new-feature) Make your changes Test your changes Commit your changes (git commit -am &#39;Add some feature&#39;) If needed please squash commits. Push to the branch (git push origin my-new-feature) Create a Pull Request"}]